@@ -1,6 +1,8 @@
 import inspect
 import unittest
 
+import pytest
+
 from radicl.probe import RAD_Probe
 from radicl.ui_tools import *
 
@@ -21,6 +23,14 @@ class TestUITools(unittest.TestCase):
         for v in ['depth', 'filtereddepth', 'rawpressure']:
             assert v in result.keys()
 
+@pytest.mark.parametrize("idx, ratio, n_samples, expected", [
+    (10, 1.1, 10, 9),
+    (1, 0.9, 10, 0)
+])
+def test_get_index_from_ratio(idx, ratio, n_samples, expected):
+    result = get_index_from_ratio(idx, ratio, n_samples)
+    assert result == expected
+
 
 if __name__ == '__main__':
     unittest.main()
